@@ -38,8 +38,6 @@ type loader struct {
 func (l *loader) Load() (state *State, err error) {
 	defer l.Recover2(&err, "app: unable to load state")
 	state = new(State)
-	state.Provider = l.loadProvider()
-	state.Flag = l.flag
 	l.imports.AddStd("os", "context", "errors")
 	l.imports.AddNamed("commander", "github.com/livebud/bud/package/commander")
 	l.imports.AddNamed("budclient", "github.com/livebud/bud/package/budclient")
@@ -47,6 +45,8 @@ func (l *loader) Load() (state *State, err error) {
 	l.imports.AddNamed("log", "github.com/livebud/bud/package/log")
 	l.imports.AddNamed("filter", "github.com/livebud/bud/package/log/filter")
 	l.imports.Add(l.module.Import("bud/internal/app/web"))
+	state.Provider = l.loadProvider()
+	state.Flag = l.flag
 	state.Imports = l.imports.List()
 	return state, nil
 }
@@ -54,13 +54,14 @@ func (l *loader) Load() (state *State, err error) {
 func (l *loader) loadProvider() *di.Provider {
 	jsVM := di.ToType("github.com/livebud/bud/package/js", "VM")
 	fn := &di.Function{
-		Name:   "loadWeb",
-		Target: l.module.Import("bud", "program"),
-		Params: []di.Dependency{
-			di.ToType("github.com/livebud/bud/package/log", "Interface"),
-			di.ToType("github.com/livebud/bud/package/gomod", "*Module"),
-			di.ToType("github.com/livebud/bud/package/budclient", "Client"),
-			di.ToType("context", "Context"),
+		Name:    "loadWeb",
+		Imports: l.imports,
+		Target:  l.module.Import("bud", "program"),
+		Params: []*di.Param{
+			{Import: "github.com/livebud/bud/package/log", Type: "Interface"},
+			{Import: "github.com/livebud/bud/package/gomod", Type: "*Module"},
+			{Import: "github.com/livebud/bud/package/budclient", Type: "Client"},
+			{Import: "context", Type: "Context"},
 		},
 		Results: []di.Dependency{
 			di.ToType(l.module.Import("bud/internal/app/web"), "*Server"),
@@ -81,9 +82,5 @@ func (l *loader) loadProvider() *di.Provider {
 		// easily
 		l.Bail(fmt.Errorf("app: unable to wire. %s", err))
 	}
-	// Add imports
-	for _, im := range provider.Imports {
-		l.imports.AddNamed(im.Name, im.Path)
-	}
 	return provider
 }
