@@ -2182,3 +2182,182 @@ func TestComplexInput(t *testing.T) {
 		{"ID":"123","Email":"alice@livebud.com","Op":{"name":"update","params":[{"Version":1,"update":true},{"Version":2,"update":false}]}}
 	`))
 }
+
+func TestRedirectBack(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.Files["controller/controller.go"] = `
+		package controller
+		import "errors"
+		type Controller struct {}
+		func (c *Controller) Index() string {
+			return "index"
+		}
+		func (c *Controller) New() string {
+			return "new"
+		}
+		func (c *Controller) Edit() string {
+			return "new"
+		}
+		func (c *Controller) Create() error {
+			return errors.New("create error")
+		}
+		func (c *Controller) Update() error {
+			return errors.New("update error")
+		}
+		func (c *Controller) Delete() error {
+			return errors.New("update error")
+		}
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	// Post request
+	req, err := app.PostRequest("/", nil)
+	is.NoErr(err)
+	req.Header.Set("Referer", "/new")
+	res, err := app.Do(req)
+	is.NoErr(err)
+	is.NoErr(res.DiffHeaders(`
+		HTTP/1.1 303 See Other
+		Location: /new
+	`))
+	// Post request, no referer
+	req, err = app.PostRequest("/", nil)
+	is.NoErr(err)
+	res, err = app.Do(req)
+	is.NoErr(err)
+	is.NoErr(res.DiffHeaders(`
+		HTTP/1.1 303 See Other
+		Location: /
+	`))
+	// Patch request
+	req, err = app.PatchRequest("/10", nil)
+	is.NoErr(err)
+	req.Header.Set("Referer", "/10/edit")
+	res, err = app.Do(req)
+	is.NoErr(err)
+	is.NoErr(res.DiffHeaders(`
+		HTTP/1.1 303 See Other
+		Location: /10/edit
+	`))
+	// Patch request, no referer
+	req, err = app.PatchRequest("/10", nil)
+	is.NoErr(err)
+	res, err = app.Do(req)
+	is.NoErr(err)
+	is.NoErr(res.DiffHeaders(`
+		HTTP/1.1 303 See Other
+		Location: /10
+	`))
+	// Delete request
+	req, err = app.DeleteRequest("/10", nil)
+	is.NoErr(err)
+	req.Header.Set("Referer", "/10")
+	res, err = app.Do(req)
+	is.NoErr(err)
+	is.NoErr(res.DiffHeaders(`
+		HTTP/1.1 303 See Other
+		Location: /10
+	`))
+}
+
+func TestInject(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.Files["log/log.go"] = `
+		package log
+		func New() *Logger { return &Logger{} }
+		type Logger struct {}
+		func (l *Logger) Info(msg string) {}
+	`
+	td.Files["session/session.go"] = `
+		package session
+		import "errors"
+		import "net/http"
+		import "app.com/log"
+		func New(log *log.Logger, w http.ResponseWriter, r *http.Request) *Session {
+			return &Session{log, w, r}
+		}
+		type Session struct {
+			log *log.Logger
+			w http.ResponseWriter
+			r *http.Request
+		}
+		func (s *Session) Set(key, value string) {
+			s.log.Info("setting session")
+			http.SetCookie(s.w, &http.Cookie{Name: key, Value: value })
+		}
+		func (s *Session) Clear() error {
+			return errors.New("session: unable to clear")
+		}
+	`
+	td.Files["db/db.go"] = `
+		package db
+		import "context"
+		var loaded = 0
+		func Load(ctx context.Context) (*Client, error) {
+			loaded++
+			return &Client{}, nil
+		}
+		type Client struct{}
+		func (c *Client) Loaded() int {
+			return loaded
+		}
+	`
+	td.Files["controller/controller.go"] = `
+		package controller
+		import "app.com/session"
+		import "app.com/db"
+		type Controller struct {
+			Session *session.Session
+			DB *db.Client
+		}
+		func (c *Controller) Create() error {
+			c.Session.Set("sessionid", "some-key")
+			return nil
+		}
+		func (c *Controller) Delete() error {
+			return c.Session.Clear()
+		}
+		func (c *Controller) Index() int {
+			return c.DB.Loaded()
+		}
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	// Test errors from dependencies
+	res, err := app.DeleteJSON("/10", nil)
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+			HTTP/1.1 500 Internal Server Error
+			Content-Type: application/json
+
+			{"error":"session: unable to clear"}
+		`))
+	// Post request continue to work
+	res, err = app.PostJSON("/", nil)
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 204 No Content
+		Set-Cookie: sessionid=some-key
+	`))
+	// Post request continue to work
+	res, err = app.GetJSON("/")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		1
+	`))
+}
